# -*- coding: utf-8 -*-

"""Console script for biocode_fims."""

import click


@click.command()
def main(args=None):
    """Console script for biocode_fims."""
    click.echo("Replace this message by putting your code into "
               "biocode_fims.cli.main")

if __name__ == "__main__":
    main()



import requests
import pandas as pd

API_BASE = 'http://biscicol.org/biocode-fims/rest/v1.1/'


def list_projects(format='titles'):
    """Lists all of the *public* projects on the Biocode FIMS"""

    params = {'includePublic': 'true'}
    project_list_url = API_BASE + 'projects/'
    r = requests.get(project_list_url, params=params)
    all_projects = r.json()
    if format == 'raw':
        return all_projects
    elif format == 'titles':
        project_dict = {project['projectTitle']: project['projectId'] \
                        for project in all_projects}
        return project_dict
    else:
        return


def list_datasets(project_id, format='code_list'):
    """Lists all of the datasets for a given project"""

    list_url = '{}projects/{}/expeditions'.format(API_BASE, project_id)
    r = requests.get(list_url)
    datasets = r.json()
    if format == 'raw':
        return datasets
    elif format == 'code_list':
        code_list = sorted([ds['expeditionCode'] for ds in datasets])
        return code_list


def dataset_contents(project_id, code_list, format='filtered_dicts'):
    """Returns the full dataset contents for a list of datasets."""

    dataset_code_string = ','.join(code_list)
    dataset_url = '{}projects/query/json'.format(API_BASE)
    dataset_payload = {'projectId': project_id,
                       'expeditions': dataset_code_string,
                       'limit': '100000'}
    dataset_r = requests.get(dataset_url, params=dataset_payload)
    dataset_json = dataset_r.json()
    if format == 'raw':
        return dataset_json['content']
    elif format == 'filtered_dicts':
        filtered_contents = [{k: v for k, v in record.items() if v} \
                                for record in dataset_json['content']]
        return filtered_contents
    elif format == 'dataframe':
        filtered_contents = [{k: v for k, v in record.items() if v} \
                                for record in dataset_json['content']]
        df = pd.DataFrame(filtered_contents)
        df = df.dropna(axis=1, how='all')
        well_order = []
        for number in range(1, 13):
            well_column = str(number).zfill(2)
            for letter in ['A', 'B', 'C', 'D', 'E', 'F', 'G', 'H']:
                well = letter + well_column
                well_order.append(well)
        df['extractionWell'] = df['extractionWell'].astype('category')
        df['extractionWell'] = df['extractionWell'].cat.set_categories(well_order, 
                                                                       ordered=True)
        df = df.sort_values(['extractionPlateID', 'extractionWell'])
        return df


if __name__ == "__main__":
    print(list_projects())
    sibn_datasets = list_datasets(12)
    print(sibn_datasets[:20])
    print(len(dataset_contents(12, sibn_datasets[:5])))



#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""The setup script."""

from setuptools import setup, find_packages

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

requirements = [
    'Click>=6.0',
    'requests',
    'pandas'
]

setup_requirements = [
    'pytest-runner',
    # TODO(MikeTrizna): put setup requirements (distutils extensions, etc.) here
]

test_requirements = [
    'pytest',
    # TODO: put package test requirements here
]

setup(
    name='biocode_fims',
    version='0.2.3',
    description="A Python client for accessing data from the Biocode FIMS database.",
    long_description=readme + '\n\n' + history,
    author="Mike Trizna",
    author_email='mike.trizna@gmail.com',
    url='https://github.com/MikeTrizna/biocode_fims',
    packages=find_packages(include=['biocode_fims']),
    entry_points={
        'console_scripts': [
            'biocode_fims=biocode_fims.cli:main'
        ]
    },
    include_package_data=True,
    install_requires=requirements,
    license="MIT license",
    zip_safe=False,
    keywords='biocode_fims',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        "Programming Language :: Python :: 2",
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6'
    ],
    test_suite='tests',
    tests_require=test_requirements,
    setup_requires=setup_requirements,
)
